==> 0.13.0.tar.gz: example/lib/configs/locales/locale_ja.dart <==
Map<String, String> localeJa = {
  // common
  'common.locale_name_ja': '日本語',
  'common.locale_name_zh_CN': '簡体中国語',

  // not_found_page
  'not_found_page.title': 'ページが見つからない',
  'not_found_page.content': 'すみません、ページが見つかりません！',

  // http
  'http.errorMessage': 'HTTPの送信に失敗しました（@statusCode）：@errorMessage',
  'http.ParamaterInvalid': '無効なパラメーター',
  'http.Unauthorized': 'キーが存在しない、間違っている、または期限切れ',
  'http.AccountPasswordInvalid': '無効なアカウントまたはパスワード',
  'http.AccountLocked': 'アカウントがロックされました',
  'http.AccountOffline': 'アカウントはオフラインだ',
  'http.Forbidden': '許可されていないリソースへのオペレーション',
  'http.Existing': 'データはすでに存在しており、操作はできない',
  'http.NotFound': '資料は存在しない',
  'http.MethodNotAllowed': 'この方法の使用は許可されていない',
  'http.ServerError': 'サーバー内のエラー',
  'http.Unknown': '未知のエラー、ネットワークの不安定さかもしれない',

  // main_page
  'main_page.home': 'ホームページ',
  'main_page.home_title': 'Flutter Waff Example',
  'main_page.widget_example': 'ウィジェット',
  'main_page.widget_example_title': 'コンポーネントのデモ',
  'main_page.utils_example': 'ツール',
  'main_page.utils_example_title': 'ツールのデモ',
  'main_page.locale_theme_example': '国際化とテーマ',
  'main_page.locale_theme_example_title': '国際化とテーマのデモ',
  'main_page.documents': 'ドキュメントの開発',

  // home_page
  'home_page.title': 'About waff',
  'home_page.intro':
      '''Wide App Flutter light-Framework (Waff for short) is a set of horizontally layered, vertical module-driven, fast-realizing business logic Flutter light framework for rapid development of Android/iOS and self-designed packaging; no need to distinguish between Android/iOS, easy implementation Develop multi-terminal releases at once.

Based on Flutter2+GetX, Waff has highly standardized the project structure, development methods, and business logic implementation. Layered packaging of commonly used functions and components, combined with development documents and routines, allows developers to quickly build App development skeletons at the beginning of the project, reach a consensus on code implementation, and focus on business logic development.

Waff is the Flutter of Pactera-BG9-IND-Dev-WF Delivery Center based on the site small blackboard App development process, extracting the engineering structure, development methods and business logic implementation, combining the excellent features of previous or participating Android/iOS projects, and abstracting the design and packaging of Flutter The light framework can provide project construction, training, development and implementation for Android/iOS App development at the same time. A rule mechanism for framework iteration, update and upgrade has been initially formed, which will continue to improve and iterate Waff.''',

  // locale_theme_example_page
  'locale_theme_example_page.change_theme_mode': '更改主题タイプ (現在:@mode)',
  'locale_theme_example_page.theme_mode_light': '明るい色',
  'locale_theme_example_page.theme_mode_dark': '暗い色',
  'locale_theme_example_page.theme_mode_system': 'システムに従う',
  'locale_theme_example_page.change_locale': '更改语言 (現在:@localeName)',
  'locale_theme_example_page.hello': 'こんにちは！',
  'locale_theme_example_page.hello_name': 'こんにちは！@name',
  'locale_theme_example_page.theme_colors':
      'ThemeData で定義できない色は、theme_colors.dart で定義してください',

  // utils_example_page
  'utils_example_page.eventBus': '全局ニュース',
  'utils_example_page.appLifecycle': 'アプリのライフサイクル',
  'utils_example_page.connectivity': 'ネットワーク状態',

  // app_lifecycle_page
  'app_lifecycle_page.title': 'アプリのライフサイクル',
  'app_lifecycle_page.intro':
      '使用方法：\n1。AppLifecycleListener.startupを使用して、start_app.dartまたは任意の場所から開始します。これはシングルトンモードです\n2。コントローラーを介して監視します\n\nこの例では、コンソールにログ情報を出力します',

  // connectivity_page
  'connectivity_page.title': 'ネットワーク状態',
  'connectivity_page.intro':
      '現在の状態：@state \n\n使用方法：\n1.ConnectivityListener.startupを使用してどこからでも起動できます。これはシングルピースモードです。\n2。コントローラーを介して監視します\n\nConnectivityStateには、WIFI、WIFI_AVAILABLE、WIFI_NOT_AVAILABLE、MOBILE、MOBILE_AVAILABLE、MOBILE_NOT_AVAILABLE、NONE7の状態が含まれます。',

  // event_bus_page
  'event_bus_page.title': 'グローバルイベント (EventBus) デモ',
  'event_bus_page.intro':
      'The global message event is defined in [services/event_bus_events.dart], the following is the example of the [ExampleEvent].',
  'event_bus_page.send_message': 'イベントを送信',
  'event_bus_page.receive_message': '受信内容：@message',
  'event_bus_page.non_message': 'イベントなし',
};

==> 2.0.0.tar.gz: example/lib/configs/locales/locale_ja.dart <==
Map<String, String> localeJa = {
  // common
  'common.locale_name_ja': '日本語',
  'common.locale_name_zh_CN': '簡体中国語',

  // not_found_page
  'not_found_page.title': 'ページが見つからない',
  'not_found_page.content': 'すみません、ページが見つかりません！',

  // http
  'http.errorMessage': 'HTTPの送信に失敗しました（@statusCode）：@errorMessage',
  'http.ParamaterInvalid': '無効なパラメーター',
  'http.Unauthorized': 'キーが存在しない、間違っている、または期限切れ',
  'http.AccountPasswordInvalid': '無効なアカウントまたはパスワード',
  'http.AccountLocked': 'アカウントがロックされました',
  'http.AccountOffline': 'アカウントはオフラインだ',
  'http.Forbidden': '許可されていないリソースへのオペレーション',
  'http.Existing': 'データはすでに存在しており、操作はできない',
  'http.NotFound': '資料は存在しない',
  'http.MethodNotAllowed': 'この方法の使用は許可されていない',
  'http.ServerError': 'サーバー内のエラー',
  'http.UnknownError': '未知のエラー、ネットワークの不安定さかもしれない',

  // main_page
  'main_page.home': 'ホームページ',
  'main_page.home_title': 'Flutter Waff Example',
  'main_page.widget_example': 'ウィジェット',
  'main_page.widget_example_title': 'コンポーネントのデモ',
  'main_page.utils_example': 'ツール',
  'main_page.utils_example_title': 'ツールのデモ',
  'main_page.locale_theme_example': '国際化とテーマ',
  'main_page.locale_theme_example_title': '国際化とテーマのデモ',
  'main_page.documents': 'ドキュメントの開発',

  // home_page
  'home_page.title': 'About waff',
  'home_page.intro':
      '''Wide App Flutter light-Framework (Waff for short) is a set of horizontally layered, vertical module-driven, fast-realizing business logic Flutter light framework for rapid development of Android/iOS and self-designed packaging; no need to distinguish between Android/iOS, easy implementation Develop multi-terminal releases at once.

Based on Flutter2+GetX, Waff has highly standardized the project structure, development methods, and business logic implementation. Layered packaging of commonly used functions and components, combined with development documents and routines, allows developers to quickly build App development skeletons at the beginning of the project, reach a consensus on code implementation, and focus on business logic development.

Waff is the Flutter of Pactera-BG9-IND-Dev-WF Delivery Center based on the site small blackboard App development process, extracting the engineering structure, development methods and business logic implementation, combining the excellent features of previous or participating Android/iOS projects, and abstracting the design and packaging of Flutter The light framework can provide project construction, training, development and implementation for Android/iOS App development at the same time. A rule mechanism for framework iteration, update and upgrade has been initially formed, which will continue to improve and iterate Waff.''',

  // locale_theme_example_page
  'locale_theme_example_page.change_theme_mode': '更改主题タイプ (現在:@mode)',
  'locale_theme_example_page.theme_mode_light': '明るい色',
  'locale_theme_example_page.theme_mode_dark': '暗い色',
  'locale_theme_example_page.theme_mode_system': 'システムに従う',
  'locale_theme_example_page.change_locale': '更改语言 (現在:@localeName)',
  'locale_theme_example_page.hello': 'こんにちは！',
  'locale_theme_example_page.hello_name': 'こんにちは！@name',
  'locale_theme_example_page.theme_colors':
      'ThemeData で定義できない色は、theme_colors.dart で定義してください',

  // utils_example_page
  'utils_example_page.eventBus': '全局ニュース',
  'utils_example_page.appLifecycle': 'アプリのライフサイクル',
  'utils_example_page.connectivity': 'ネットワーク状態',

  // app_lifecycle_page
  'app_lifecycle_page.title': 'アプリのライフサイクル',
  'app_lifecycle_page.intro':
      '使用方法：\n1。AppLifecycleListener.startupを使用して、start_app.dartまたは任意の場所から開始します。これはシングルトンモードです\n2。コントローラーを介して監視します\n\nこの例では、コンソールにログ情報を出力します',

  // connectivity_page
  'connectivity_page.title': 'ネットワーク状態',
  'connectivity_page.intro':
      '現在の状態：@state \n\n使用方法：\n1.ConnectivityListener.startupを使用してどこからでも起動できます。これはシングルピースモードです。\n2。コントローラーを介して監視します\n\nConnectivityState：\nBLUETOOTH、BLUETOOTH_AVAILABLE、BLUETOOTH_NOT_AVAILABLE、WIFI、WIFI_AVAILABLE、WIFI_NOT_AVAILABLE、ETHERNET、ETHERNET_AVAILABLE、ETHERNET_NOT_AVAILABLE、MOBILE、MOBILE_AVAILABLE、MOBILE_NOT_AVAILABLE、NONE',

  // event_bus_page
  'event_bus_page.title': 'グローバルイベント (EventBus) デモ',
  'event_bus_page.intro':
      'The global message event is defined in [services/event_bus_events.dart], the following is the example of the [ExampleEvent].',
  'event_bus_page.send_message': 'イベントを送信',
  'event_bus_page.receive_message': '受信内容：@message',
  'event_bus_page.non_message': 'イベントなし',
};
